@@ -17,6 +17,7 @@ import shutil
 from collections.abc import KeysView
 from decimal import Decimal
 from io import BytesIO
+from os import replace
 from pathlib import Path
 from subprocess import PIPE, run
 from tempfile import NamedTemporaryFile
@@ -285,6 +286,48 @@ class Extend_Pdf:
         data = {'application/pdf': bio.read()}
         return data
 
+    @property
+    def docinfo(self) -> Dictionary:
+        """
+        Access the (deprecated) document information dictionary.
+
+        The document information dictionary is a brief metadata record that can
+        store some information about the origin of a PDF. It is deprecated and
+        removed in the PDF 2.0 specification (not deprecated from the
+        perspective of pikepdf). Use the ``.open_metadata()`` API instead, which
+        will edit the modern (and unfortunately, more complicated) XMP metadata
+        object and synchronize changes to the document information dictionary.
+
+        This property simplifies access to the actual document information
+        dictionary and ensures that it is created correctly if it needs to be
+        created.
+
+        A new, empty dictionary will be created if this property is accessed
+        and dictionary does not exist. (This is to ensure that convenient code
+        like ``pdf.docinfo[Name.Title] = "Title"`` will work when the dictionary
+        does not exist at all.)
+
+        You can delete the document information dictionary by deleting this property,
+        ``del pdf.docinfo``. Note that accessing the property after deleting it
+        will re-create with a new, empty dictionary.
+        """
+        if Name.Info not in self.trailer:
+            self.trailer.Info = self.make_indirect(Dictionary())
+        return self.trailer.Info
+
+    @docinfo.setter
+    def docinfo(self, new_docinfo: Dictionary):
+        if not new_docinfo.is_indirect:
+            raise ValueError(
+                "docinfo must be an indirect object - use Pdf.make_indirect"
+            )
+        self.trailer.Info = new_docinfo
+
+    @docinfo.deleter
+    def docinfo(self):
+        if Name.Info in self.trailer:
+            del self.trailer.Info
+
     def open_metadata(
         self,
         set_pikepdf_as_editor: bool = True,
@@ -943,6 +986,67 @@ class Extend_Page:
         check_is_box(value)
         self.obj['/TrimBox'] = value
 
+    @property
+    def resources(self):
+        return self.obj['/Resources']
+
+    def add_resource(
+        self,
+        res: Object,
+        res_type: Name,
+        name: Optional[Name] = None,
+        *,
+        prefix: str = '',
+        replace_existing: bool = True,
+    ) -> str:
+        """Adds a new resource to the page's Resources dictionary.
+
+        If the Resources dictionaries do not exist, they will be created.
+
+        Args:
+            self: The object to add to the resources dictionary.
+            res: The resource dictionary object to add.
+            res_type: Should be one of the following Resource dictionary types:
+                ExtGState, ColorSpace, Pattern, Shading, XObject, Font, Properties.
+            name: The name of the object. If omitted, a random name will be
+                generated with enough randomness to be globally unique.
+            prefix: A prefix for the name of the object. Allows conveniently
+                namespacing when using random names, e.g. prefix="Im" for images.
+                Mutually exclusive with name parameter.
+            replace_existing: If the name already exists in one of the resource
+                dictionaries, remove it.
+        Returns:
+            The name of the object.
+
+        Example:
+            resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
+        """
+        if not Name.Resources in self.obj:
+            self.obj.Resources = Dictionary()
+        elif not isinstance(self.obj.Resources, Dictionary):
+            raise TypeError("Page /Resources exists but is not a dictionary")
+        resources = self.obj.Resources
+
+        if not res_type in resources:
+            resources[res_type] = Dictionary()
+
+        if name is not None and prefix:
+            raise ValueError("Must specify one of name= or prefix=")
+        if name is None:
+            name = Name.random(prefix=prefix)
+
+        for res_dict in resources.as_dict().values():
+            if not isinstance(res_dict, Dictionary):
+                continue
+            if name in res_dict:
+                if replace_existing:
+                    del res_dict[name]
+                else:
+                    raise ValueError(f"Name {name} already exists in page /Resources")
+
+        resources[res_type][name] = res
+        return name
+
     def __repr__(self):
         return repr(self.obj).replace('Dictionary', 'Page')
 
